@@ -12,6 +12,7 @@
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kstddirs.h>
+#include <kseparator.h>
 
 #include <qtoolbutton.h>
 #include <qiconset.h>
@@ -86,9 +87,7 @@ Principal::Principal( const char *name)
         logoWidget->setAutoResize(true);
         logoWidget->setPixmap( QPixmap(locate("data","aktion/toolbar/aktion_logo.png")) );
 
-	line = new QFrame(mainwidget, "separator");
-        line->setMaximumHeight(1);
-        line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
+	line = new KSeparator( KSeparator::HLine, mainwidget);
 
 	volumeSlider = new QSlider(mainwidget);
 	volumeSlider->hide();
@@ -341,7 +340,7 @@ void Principal::click_open()
     }
     else
     {
-        KMessageBox::sorry( 0L, i18n("Only local files are supported yet." ) );
+        KMessageBox::sorry( 0L, i18n("Only local files are currently supported." ) );
         fileName = "";
     }
 
@@ -843,3 +842,4 @@ void Principal::executableChanged()
          click_open();
    }
 }
+#include "principal.moc"
