@@ -22,14 +22,16 @@
 #include <qfile.h>
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qframe.h>
+#include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qlineedit.h>
 
 #include <kbuttonbox.h>
 #include <kfiledialog.h>
-#include <qbttngrp.h>
-#include <qradiobt.h>
-#include <qlined.h>
+#include <kseparator.h>
 #include <kapp.h>
+
+
 #include <unistd.h>
 #include "portablekde.h"
 #include "execdlg.h"
@@ -80,10 +82,8 @@ ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
 //	ruler above the sliderlayout
 
 	mainlayout->addSpacing(5);
-	QFrame *rulersl = new QFrame(this);
-	rulersl->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	rulersl->setMinimumSize(50,2);
-	mainlayout->addWidget(rulersl);
+        KSeparator* sep = new KSeparator( KSeparator::HLine, this);
+	mainlayout->addWidget(sep);
 	mainlayout->addSpacing(5);
 
 //	sliders, controlpanels
@@ -100,11 +100,8 @@ ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
 //  hruler below the sliderlayout
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler = new QFrame(this);
-	ruler->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler->setMinimumSize(50,2);
-	mainlayout->addWidget(ruler);
-
+        sep = new KSeparator( KSeparator::HLine, this);
+	mainlayout->addWidget(sep);
 	mainlayout->addSpacing(5);
 
 // buttons
@@ -158,7 +155,7 @@ void ExecDlg::updateCpuUsage()
 	{
 		cpuusagetimer->stop();
 		accept();
-		PortableKDE::KMsgSorry(this,i18n("Your synthesis has been interruped due to too high cpu load."));
+		PortableKDE::KMsgSorry(this,i18n("Your synthesis has been interrupted due to excessive cpu load."));
 		/*
 		KMsgBox::message(this,i18n("Error"),
 		  i18n("Your synthesis has been interrupted due to too high cpu load."),
@@ -195,3 +192,4 @@ void ExecDlg::saveSession()
 		structure->saveSession(QFile::encodeName(filename));
 	}
 }
+#include "execdlg.moc"
