@@ -36,7 +36,7 @@ protected:
 	Structure *structure;
 	QListBox *listbox;
 
-	vector<StructurePort *> listports;
+	std::vector<StructurePort *> listports;
 public:
 	PortPosDlg(QWidget *parent, Structure *structure);
 
