@@ -23,12 +23,12 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlistbox.h>
-#include <qframe.h>
 #include <kbuttonbox.h>
 #include <qbttngrp.h>
 #include <qradiobt.h>
 #include <qlined.h>
 #include <kapp.h>
+#include <kseparator.h>
 #include <stdio.h>
 #include <set>
 #include <arts/debug.h>
@@ -60,11 +60,8 @@ RetrieveDlg::RetrieveDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler2 = new QFrame(this);
-	ruler2->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler2->setMinimumSize(50,2);
+	KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler2);
-
 	mainlayout->addSpacing(5);
 
 // listwidget
@@ -92,11 +89,8 @@ RetrieveDlg::RetrieveDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler = new QFrame(this);
-	ruler->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler->setMinimumSize(50,2);
+	KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler);
-
 	mainlayout->addSpacing(5);
 
 // buttons
@@ -134,3 +128,4 @@ const char * RetrieveDlg::result()
 	}
 	return(0);
 }
+#include "retrievedlg.moc"
