@@ -25,7 +25,7 @@
 #include "structure.h"
 
 class Session :public ExecutableStructure {
-	vector<string> *session;
+	std::vector<std::string> *session;
 public:
 	Session();
 	~Session();
