@@ -184,6 +184,11 @@ bool Structure::save(const char *filename)
 	fclose(file);
 
 	delete savePtr;
+
+/* tell the server to rescan for structures */
+	Arts::SoundServerV2 server = Arts::Reference("global:Arts_SoundServerV2");
+	if(!server.isNull()) server.checkNewObjects();
+
 	return true;
 }
 
