@@ -28,6 +28,6 @@
 
 #include "artsbuilder.h"
 
-Arts::ModuleInfo makeModuleInfo(const string& name);
+Arts::ModuleInfo makeModuleInfo(const std::string& name);
 
 #endif /* MODULEINFO_H */
