@@ -21,8 +21,7 @@ protected:
 	ModuleDesc_wref _parent;
 	bool _isConnected;
 	bool _hasValue;
-	float _floatValue;
-	string _stringValue;
+	Any	 _value;
 	long _ID;
 	long _oldID;
 	list<long> oldConnections;
@@ -49,6 +48,10 @@ public:
 
 	string stringValue();
 	void stringValue( const string& _new_value );
+
+	Any value();
+	void value( const Any& _new_value );
+
 	bool connectTo( PortDesc port );
 	void internalConnectInput( PortDesc port );
 	void disconnectFrom( PortDesc port );
@@ -201,8 +204,7 @@ void PortDesc_impl::constructor(ModuleDesc parent, const string& name,
 	_parent = parent;
 	_isConnected = false;
 	_hasValue = false;
-	_floatValue = 0.0;
-	_stringValue = "";
+	_value.type = _type.dataType;
 
 	if(!parent.isNull())
 	{
@@ -318,32 +320,60 @@ vector<PortDesc> *PortDesc_impl::connections()
 float PortDesc_impl::floatValue()
 {
 	assert(_hasValue);
-	assert(_type.dataType == Arts::audio_data);
-	return _floatValue; 
+	assert(_type.dataType == "float");
+
+	Buffer b;
+	b.write(_value.value);
+	return b.readFloat();
 }
 
 void PortDesc_impl::floatValue( float _new_value )
 {
 	assert(!_isConnected);
 	assert(_type.direction == Arts::input);
-	assert(_type.dataType == Arts::audio_data);
-	_floatValue = _new_value;
+	assert(_type.dataType == "float");
+	assert(_value.type == "float");
+
+	Buffer b;
+	b.writeFloat(_new_value);
+	b.read(_value.value, b.size());
 	_hasValue = true;
 }
 
 string PortDesc_impl::stringValue()
 {
 	assert(_hasValue);
-	assert(_type.dataType == Arts::string_data);
-	return _stringValue;
+	assert(_type.dataType == "string");
+	assert(_value.type == "string");
+
+	string result;
+	Buffer b;
+	b.write(_value.value);
+	b.readString(result);
+	return result;
 }
 
 void PortDesc_impl::stringValue( const string& _new_value )
 {
 	assert(!_isConnected);	// shouldn't happen, but check anyway
 	assert(_type.direction == Arts::input);
-	assert(_type.dataType == Arts::string_data);
-	_stringValue = _new_value;
+	assert(_type.dataType == "string");
+
+	Buffer b;
+	b.writeString(_new_value);
+	b.read(_value.value, b.size());
+	_hasValue = true;
+}
+
+Any PortDesc_impl::value()
+{
+	assert(_hasValue);
+	return _value;
+}
+
+void PortDesc_impl::value( const Any& _new_value )
+{
+	_value = _new_value;
 	_hasValue = true;
 }
 
@@ -384,9 +414,9 @@ bool PortDesc_impl::connectTo( PortDesc port )
 
 	if( _type.direction == Arts::input )
 	{
-		if(!_isConnected)
+		if(!_isConnected || _type.isMultiPort)
 		{
-			assert(_connections.empty());
+			assert(_connections.empty() || _type.isMultiPort);
 			_connections.push_back(port);
 
 			port.internalConnectInput(self());
@@ -674,13 +704,19 @@ vector<string> *PortDesc_impl::saveToList()
 	sqprintf(list,"id=%ld",_ID);
 	if(_hasValue)
 	{
-		if(_type.dataType == Arts::string_data)
+		if(_type.dataType == "string")
 		{
-			sqprintf(list,"string_data=%s",_stringValue.c_str());
+			sqprintf(list,"string_data=%s",stringValue().c_str());
 		}
-		if(_type.dataType == Arts::audio_data)
+		else if(_type.dataType == "float")
 		{
-			sqprintf(list,"audio_data=%2.5f",_floatValue);
+			sqprintf(list,"audio_data=%2.5f",floatValue());
+		}
+		else
+		{
+			Buffer b;
+			_value.writeType(b);
+			sqprintf(list,"any_data=%s",b.toString("value").c_str());
 		}
 	}
 
@@ -779,6 +815,15 @@ void PortDesc_impl::loadFromList(const vector<string>& list)
 				floatValue(atof(param.c_str()));
 			} else if(cmd == "string_data") {
 				stringValue(param);
+			} else if(cmd == "any_data") {
+				Buffer b;
+				if(b.fromString(param,"value"))
+				{
+					Any any;
+					any.readType(b);
+					if(!b.readError() && !b.remaining())
+						value(any);
+				}
 			} else if(cmd == "id") {
 				_oldID = atol(param.c_str());
 			} else if(cmd == "connect_to") {
@@ -879,7 +924,7 @@ void StructureDesc_impl::loadFromList(const vector<string>& list)
 				// port:
 				PortType type;
 				type.direction = Arts::input;
-				type.dataType = Arts::audio_data;
+				type.dataType = "float";
 				type.connType = Arts::conn_stream;
 
 				StructurePortDesc spd =
@@ -1178,10 +1223,10 @@ PortType loadTypeFromList(const vector<string>& list)
 				loadstate += 1;
 			} else if(cmd == "datatype") {
 				if(param == "audio") {
-					result.dataType = Arts::audio_data;
+					result.dataType = "float";
 				}
 				else if(param == "string") {
-					result.dataType = Arts::string_data;
+					result.dataType = "string";
 				}
 				else assert(false);
 
@@ -1270,13 +1315,17 @@ vector<string> *saveTypeToList(const PortType& type)
 					break;
 		default: assert(false);		// should never happen!
 	}
-	switch(type.dataType)
+	if(type.dataType == "float")
 	{
-		case Arts::audio_data: sqprintf(list,"datatype=audio");
-					break;
-		case Arts::string_data: sqprintf(list,"datatype=string");
-					break;
-		default: assert(false);		// should never happen!
+		sqprintf(list,"datatype=audio");
+	}
+	else if(type.dataType == "string")
+	{
+		sqprintf(list,"datatype=string");
+	}
+	else
+	{
+		assert(false);				// should never happen!
 	}
 	switch(type.connType)
 	{
