@@ -25,8 +25,8 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlistbox.h>
-#include <qframe.h>
 #include <kbuttonbox.h>
+#include <kseparator.h>
 #include <qbttngrp.h>
 #include <qradiobt.h>
 #include <qlined.h>
@@ -60,9 +60,7 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler2 = new QFrame(this);
-	ruler2->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler2->setMinimumSize(50,2);
+	KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler2);
 
 	mainlayout->addSpacing(5);
@@ -89,11 +87,8 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler = new QFrame(this);
-	ruler->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler->setMinimumSize(50,2);
+	KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler);
-
 	mainlayout->addSpacing(5);
 
 // buttons
@@ -131,3 +126,4 @@ QString ChooseBusDlg::result()
 	}
 	return(0);
 }
+#include "choosebusdlg.moc"
