@@ -6,6 +6,7 @@
 #include "levelmeters.h"
 
 PeakBar::PeakBar(QWidget *parent): LevelMeter(parent) {
+	clipped = false;
 	displayMinPeak= false;
 	horizontalMode= false;
 	currentValue= 0.0f;
@@ -39,12 +40,15 @@ void PeakBar::checkMinMax() {
 	if (mustRecheck) {
 		maxValue= 0.f;
 		minValue= 1.f;
+		clipped = false;
 		for (QListIterator<Observation> it(lastValues); it.current(); ++it) {
 			float value= it.current()->value;
 			if (value>maxValue)
 				maxValue= value;
 			if (value<minValue)
 				minValue= value;
+			if (value > 1.f)
+				clipped = true;
 		}
 	}
 }
@@ -55,12 +59,12 @@ void PeakBar::drawContents(QPainter *p)
 
 	checkMinMax();
 	
-	p->setBrush(darkBlue);
+	p->setBrush(clipped ? darkRed : darkBlue);
 	p->setPen(NoPen);
 	p->drawRect(size);
 		
 	QRect bar= size;
-	p->setBrush(blue);
+	p->setBrush(clipped ? red : blue);
 	if (horizontalMode) {
 		bar.setWidth((int)(bar.width()*currentValue));
 	} else {
@@ -83,6 +87,9 @@ void PeakBar::drawContents(QPainter *p)
 }
 		
 void PeakBar::setValue(float f) {
+	if (f > 1.f)
+		clipped = true;
+
 	currentValue= f;
 	if (f>=maxValue)
 		maxValue= f;
@@ -223,3 +230,4 @@ void StereoLedMeters::setValues(float leftVal, float rightVal) {
 	right.setValue(rightVal);
 }
 
+#include "levelmeters.moc"
