@@ -1,17 +1,45 @@
+    /*
+
+    Copyright (C) 2000-2001 Stefan Westerfeld
+	                        <stefan@space.twc.de>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    */
+
 #include "main.h"
 #include "main.moc"
 #include "levelmeters.h"
 #include "objectmanager.h"
 #include "midimanagerview.h"
+#include "debug.h"
+#include "artsversion.h"
+#include "kartsfloatwatch.h"
 #include <math.h>
 #include <qslider.h>
 #include <qpushbutton.h>
 #include <kaction.h>
 #include <kled.h>
 #include <kmessagebox.h>
+#include <klistview.h>
+#include <kdebug.h>
 #include <audiomanager.h>
 #include <iostream>
+#include <map>
 
+using namespace std;
 using namespace Arts;
 
 void FreeVerbView::closeEvent(QCloseEvent *e)
@@ -22,27 +50,27 @@ void FreeVerbView::closeEvent(QCloseEvent *e)
 
 FreeVerbView::FreeVerbView(SimpleSoundServer server) : server(server)
 {
-	{
-		freeverb = DynamicCast(server.createObject("Arts::Synth_FREEVERB"));
-		assert(!freeverb.isNull());
-		freeverb.start();
+	freeverb = DynamicCast(server.createObject("Arts::Synth_FREEVERB"));
+	arts_assert(!freeverb.isNull());
+	freeverb.start();
 
-		// put it into the effect chain
-		effectID = server.outstack().insertBottom(freeverb,"FreeVerb");
+	// put it into the effect chain
+	effectID = server.outstack().insertTop(freeverb,"FreeVerb");
+
+	GenericGuiFactory factory;
+	Widget gui = factory.createGui(freeverb);
 
-		freeverbui = new FreeVerbUI(freeverb);
-	}
 	QBoxLayout * l = new QHBoxLayout( this );
-	l->setAutoAdd(TRUE);
-	QLabel *label = new QLabel (this);
-	label->setText( "TODO: implement options for freeverb the proper way" );
+	if(!gui.isNull())
+		l->add(new KArtsWidget(gui, this));
+	else
+		l->add(new QLabel(i18n("No GUI found for this effect."), this));
 	l->freeze();
 	show();
 }
 
 FreeVerbView::~FreeVerbView()
 {
-	delete freeverbui;
 	// remove effect
 	server.outstack().remove(effectID);
 }
@@ -114,6 +142,50 @@ FFTScopeView::~FFTScopeView()
 	server.outstack().remove(effectID);
 }
 
+MediaTypesView::MediaTypesView()
+{
+	QBoxLayout *l= new QHBoxLayout(this);
+	l->setAutoAdd(true);
+
+	KListView *listView = new KListView(this);
+	listView->addColumn(i18n("Media Type"));
+
+	Arts::TraderQuery q;
+	std::vector<Arts::TraderOffer> *results = q.query();
+	std::map<std::string, bool> done;
+	QString str;
+
+	for(std::vector<Arts::TraderOffer>::iterator i = results->begin(); i != results->end(); i++)
+	{
+		std::vector<string> *ext = (*i).getProperty("Extension");
+
+		for(vector<string>::iterator it = ext->begin(); it != ext->end(); it++)
+		{
+			if(!(*it).length() || done[*it])
+			    continue;
+
+			done[*it] = true;
+			(void) new QListViewItem(listView, (*it).c_str());
+		}
+		delete ext;
+	}
+	delete results;
+
+	l->activate();
+	show();
+	setFixedSize(300,200);
+}
+
+MediaTypesView::~MediaTypesView()
+{
+}
+
+void MediaTypesView::closeEvent(QCloseEvent *e)
+{
+	e->accept();
+	emit closed();
+}
+
 
 
 ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server)
@@ -123,7 +195,7 @@ ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server)
 	//l->setAutoAdd(TRUE);
 
 	RealtimeStatus rs= server.realtimeStatus();
-    l->addWidget(new QLabel(rs==rtRealtime? 
+    l->addWidget(new QLabel(rs==rtRealtime?
 							i18n("Artsd is running with realtime scheduling."):
 							rs==rtNoSupport?
 							i18n("Your system does not support realtime scheduling."):
@@ -134,13 +206,13 @@ ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server)
 								 "does not (is artswrapper suid root?)."),
 							this, "realtimeLabel"));
 	l->addSpacing(10);
-	
-	suspendLabel= new QLabel(i18n("Determining suspend status..."), 
+
+	suspendLabel= new QLabel(i18n("Determining suspend status..."),
 							 this, "suspendLabel");
 	l->addWidget(suspendLabel);
 	l->addSpacing(6);
 	l->setMargin(6);
-	
+
 	suspendButton= new QPushButton(this, "suspendButton");
 	suspendButton->setText(i18n("&Suspend Now"));
 	l->addWidget(suspendButton);
@@ -163,10 +235,10 @@ void ArtsStatusView::updateStatus()
 	long seconds= server.secondsUntilSuspend();
 	if (seconds<0)
 		suspendLabel->setText(i18n("The aRts sound daemon will not autosuspend right\n"
-								  " now, since there are active modules."));
+								  "now since there are active modules."));
 	else if (seconds==0)
-		suspendLabel->setText(i18n("The aRts sound daemon is suspended, legacy\n "
-								  "applications can use the soundcard now."));
+		suspendLabel->setText(i18n("The aRts sound daemon is suspended. Legacy\n "
+								  "applications can use the sound card now."));
 	else
 		suspendLabel->setText(i18n("Autosuspend will happen in %1 seconds.").
 							 arg(seconds));
@@ -181,13 +253,13 @@ void ArtsStatusView::closeEvent(QCloseEvent *e)
 
 
 
-VControl::VControl(QWidget *parent) : QFrame(parent), scopeView(0),
+VControl::VControl(QWidget *parent) : QFrame(parent), scopeView(0), mediaView(0),
 	freeVerbView(0), audioManager(0), artsStatusView(0), midiManagerView(0),
-	server(Reference("global:Arts_SoundServer"))
+	server(Reference("global:Arts_SoundServerV2")), inUpdate(false)
 {
    	if(server.isNull())
    	{
-		KMessageBox::error( 0, i18n("Connection to the soundserver failed - make sure that artsd is really running and your kdelibs version is not older than kdemultimedia."));
+		KMessageBox::error( 0, i18n("Connection to the soundserver failed - make sure that artsd is really running and that your kdelibs version is not older than kdemultimedia."));
 		exit(1);
    	}
 	boxLayout = new QHBoxLayout( this );
@@ -205,7 +277,6 @@ VControl::VControl(QWidget *parent) : QFrame(parent), scopeView(0),
 	// 1000 => 0.125
 	// 1200 => 0.0 (forced)
 
-	QSlider *slider;
 	slider = new QSlider(0,1200,100,400,QSlider::Vertical,this,"volumeslider");
 	connect(slider, SIGNAL(valueChanged(int)), this, SLOT(setVolume(int)));
 	slider->setTickmarks( QSlider::Right );
@@ -213,23 +284,16 @@ VControl::VControl(QWidget *parent) : QFrame(parent), scopeView(0),
 	boxLayout->activate();
 
 	show();
-	/*
-	   create a stereo volume control and push it into the
-	   effect chain
-	*/
-	{
-		// create a new stereo volume control object on the server
-		svc = DynamicCast(server.createObject("Arts::StereoVolumeControl"));
-		assert(!svc.isNull());
-		svc.start();
-
-		// put it into the effect chain
-		effectID = server.outstack().insertBottom(svc,"Volume Control");
-	}
+	svc = server.outVolume();
+	assert(!svc.isNull());
 
 	QTimer *updatescalestimer = new QTimer(this);
 	updatescalestimer->start(100);
 	connect(updatescalestimer,SIGNAL(timeout()),this,SLOT(updateScales()));
+
+	KArtsFloatWatch *watch = new KArtsFloatWatch(svc, "scaleFactor_changed", this);
+	connect(watch, SIGNAL(valueChanged(float)), this, SLOT(updateVolume(float)));
+	updateVolume(svc.scaleFactor());
 }
 
 VControl::~VControl()
@@ -237,10 +301,9 @@ VControl::~VControl()
 	removeScopeView();
 	removeFreeVerbView();
 	removeAudioManager();
+	removeMediaView();
 	removeArtsStatusView();
 	removeMidiManager();
-	// remove effect from effect chain
-	server.outstack().remove(effectID);
 }
 
 void VControl::updateScales()
@@ -250,12 +313,26 @@ void VControl::updateScales()
 
 void VControl::setVolume(int vol)
 {
+	if(inUpdate) return;
+
 	float volume = pow(2.0,(400.0 - vol)/200.0);
 	if(vol == 1200) volume = 0.0;
 
 	svc.scaleFactor(volume);
 }
 
+void VControl::updateVolume(float volume)
+{
+	/*
+	 * the inUpdate thing is important, because it stops us from sending the
+	 * value to the server again - if we did that, two clients could bounce
+	 * volume changes between the server and the clients
+	 */
+	inUpdate = true;
+	slider->setValue((volume < 0.001)?1200:(400 - 200 * log(volume)/log(2.0)));
+	inUpdate = false;
+}
+
 void VControl::useOldVolumeBar(int old)
 {
 	delete stereoMeter;
@@ -296,6 +373,15 @@ void VControl::showAudioManager()
 	}
 }
 
+void VControl::showMediaView()
+{
+	if(!mediaView)
+	{
+		mediaView = new MediaTypesView();
+		connect(mediaView,SIGNAL(closed()),this,SLOT(removeMediaView()));
+	}
+}
+
 void VControl::showArtsStatusView()
 {
 	if(!artsStatusView)
@@ -338,21 +424,18 @@ void VControl::removeFreeVerbView()
 	freeVerbView = 0;
 }
 
+void VControl::removeMediaView()
+{
+	if(mediaView) delete mediaView;
+	mediaView = 0;
+}
+
 void VControl::removeArtsStatusView()
 {
 	if(artsStatusView) delete artsStatusView;
 	artsStatusView = 0;
 }
 
-void MainWindow::closeEvent(QCloseEvent *)
-{
-	// this is to prevent some collision between Qt and the MCOP I/O
-	// system ... needs more investigations
-	delete vc;
-	cout << "hack: exit" << endl;
-	exit(1);
-}
-
 void MainWindow::toggleVolumeBar()
 {
 	vc->useOldVolumeBar(showOldVolumeDisplay->isChecked());
@@ -370,12 +453,14 @@ MainWindow::MainWindow() : KMainWindow(0)
 		SLOT(showArtsStatusView()), actionCollection(), "view_arts_statusview");
 	(void)new KAction(i18n("View &Midi Manager"), 0, vc,
 		SLOT(showMidiManager()), actionCollection(), "view_midi_manager");
+	(void)new KAction(i18n("View Available Media &Types"), 0, vc,
+		SLOT(showMediaView()), actionCollection(), "view_media_types");
 	(void)new KAction(i18n("Free&Verb"), 0, vc,
 		SLOT(showFreeVerbView()), actionCollection(), "view_freeverb");
 	showOldVolumeDisplay=
 		new KToggleAction(i18n("&Leds-like volume display"), 0, this,
 		SLOT(toggleVolumeBar()), actionCollection(), "old_volume_display");
-	
+
 	createGUI("artscontrol.rc");
 	resize(20,300);
 	show();
@@ -384,18 +469,19 @@ MainWindow::MainWindow() : KMainWindow(0)
 int main(int argc, char **argv)
 {
 	KAboutData aboutData( "artscontrol", I18N_NOOP("aRts control"),
-		"0.1", "Control tool for the aRts server",
+		ARTS_VERSION, I18N_NOOP("Control tool for the aRts server"),
 			KAboutData::License_GPL, "(c) 2000 Stefan Westerfeld");
 
   	KCmdLineArgs::init( argc, argv, &aboutData );
 
-	// setup mcop communication
-	//QIOManager qiomanager;
-	Dispatcher dispatcher; //(&qiomanager);
-
 	KApplication app(argc, argv);
+
+	// setup mcop communication
+	QIOManager qiomanager;
+	Dispatcher dispatcher(&qiomanager);
+
 	ObjectManager::the()->provideCapability("kdegui");
 
-	new MainWindow;
+	app.setMainWidget(new MainWindow);
 	return app.exec();
 }
