@@ -24,13 +24,13 @@
 
 #include <qdialog.h>
 #include <qcombobox.h>
-#include <string>
+#include <qcstring.h>
 
 class MidiInstDlg :public QDialog {
 	Q_OBJECT
 	QComboBox *box;
 public:
 	MidiInstDlg(QWidget *parent);
-	std::string filename();
+	QCString filename();
 };
 #endif
