@@ -5,23 +5,20 @@
  *   they refer to.  The routine load_fff_patch is adapted from "load_instrument",
  *   which is Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>.
  *		-- Greg Lee, lee@Hawaii.edu, June, 1997.
- * $Id: fffload.cpp,v 1.2 2001/01/19 09:17:50 coolo Exp $
+ * $Id: fffload.cpp,v 1.3 2001/04/12 09:07:47 garbanzo Exp $
  */
 
+#include <sys/types.h>
+#include <sys/stat.h>
+
 #include <stdio.h>
 #include <fcntl.h>
 #include <ctype.h>
 #include <errno.h>
 #include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <strings.h>
 
-#if defined (__FreeBSD__) || defined(__bsdi__)
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
 
 #include "config.h"
 #include "common.h"
