@@ -1,7 +1,7 @@
 /*
    kmidi
 
-   $Id: playlist.cpp,v 1.30 2000/09/03 05:42:45 waba Exp $
+   $Id: playlist.cpp,v 1.31 2000/12/01 21:59:02 malte Exp $
 
    Copyright 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -35,6 +35,7 @@
 #include "playlist.h"
 #include "playlist.moc"
 #include "kmidi.h"
+#include "midiapplication.h"
 
 #define BORDER_WIDTH 2
 
@@ -46,9 +47,6 @@ char fontrefstring2[]="01234567890";
 char fontrefstring3[]="00  00:00";
 
 
-extern KApplication *thisapp;
-extern KMidi *kmidi;
-
 
 PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
 	int *current_playlist_ptr, QStringList *listplaylists)
