@@ -1,5 +1,5 @@
 /*
-	$Id: resample_l.cpp,v 1.2 2001/01/19 09:17:50 coolo Exp $
+	$Id: resample_l.cpp,v 1.3 2001/04/12 09:09:23 garbanzo Exp $
 
     TiMidity++ -- MIDI to WAVE converter and player
     Copyright (C) 1999 Masanao Izumo <mo@goice.co.jp>
@@ -23,11 +23,7 @@
 
 #include <math.h>
 #include <stdio.h>
-#if defined(__FreeBSD__) || defined(__bsdi__)
 #include <stdlib.h>
-#else
-#include <malloc.h>
-#endif
 
 #include "config.h"
 #include "common.h"
