@@ -13,11 +13,13 @@ class Volume
   Volume( int channels = 2, int maxVolume = 100 );
 
   void setAllVolumes( int value )
-       { v_volumes.fill( volrange(value) ); };
-  void setVolume( int channel, int value )
-       { v_volumes[ channel ] = volrange(value); };
-  int  operator[](int channel ) const      { return v_volumes[channel]; };
-  int  getVolume( int channel ) const      { return v_volumes[channel]; };
+    { v_volumes.fill( volrange(value) ); };
+  void setVolume( unsigned channel, int value )
+    { if( channel<v_volumes.size() ) v_volumes[ channel ] = volrange(value); };
+  int  operator[]( unsigned channel ) const
+    { return (channel<v_volumes.size()) ? v_volumes[channel] : 0; };
+  int  getVolume( unsigned channel ) const
+    { return (channel<v_volumes.size()) ? v_volumes[channel] : 0; };
   int  maxVolume() const { return v_maxVolume; };
   int  channels() const { return v_volumes.size(); };
 
