@@ -1,12 +1,13 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: docking.h,v 1.8 1999/11/14 05:55:17 ettrich Exp $
+ * $Id: docking.h,v 1.9 2001/03/25 04:13:24 tibirna Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
  *
  * This file was contributed by Harri Porten <porten@tu-harburg.de>
+ * Latest changes (dynamic tooltips) by Cristian Tibirna <tibirna@kde.org>
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -36,12 +37,12 @@
 #include <qpoint.h>
 #include <kdockwindow.h>
 
-extern int 	ibytes;
-extern int 	obytes;
+extern int      ibytes;
+extern int      obytes;
 
 class KSCD;
 
-class DockWidget : public KDockWindow {
+class DockWidget : public KSystemTray {
 
   Q_OBJECT
 
@@ -49,6 +50,12 @@ public:
   DockWidget( KSCD* parent, const char *name=0);
   ~DockWidget();
 
+public slots:
+  void setToolTip(const QString& text);
+
+private:
+  QString tip;
+
 };
 
 #endif
