@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.15 2001/06/18 11:01:07 dfoerste Exp $
+ * $Id: plat_linux.c,v 1.15.2.2 2001/09/24 12:05:57 mklingens Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.15 2001/06/18 11:01:07 dfoerste Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.15.2.2 2001/09/24 12:05:57 mklingens Exp $";
 
 #if defined(__linux__)
 
@@ -61,6 +61,7 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.15 2001/06/18 11:01:07 dfoe
 #include <sys/time.h>
 #include <sys/ioctl.h>
 #include <linux/cdrom.h>
+#include <linux/version.h>
 
 #include "include/wm_cdda.h"
 #include "include/wm_struct.h"
@@ -247,7 +248,7 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
  * send packet over cdrom interface
  * kernel >= 2.2.16
  *----------------------------------------*/
-#ifdef CDROM_SEND_PACKET	
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,2,16))
 
   struct cdrom_generic_command cdc;
   struct request_sense sense;
