@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: smtp.h,v 1.6 1999/06/21 15:48:03 welk Exp $
+ * $Id: smtp.h,v 1.7 2001/03/11 15:33:54 dfoerste Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -74,6 +74,7 @@ public:
     QString getLastLine(){return lastLine;};
     
     void setSenderAddress(const QString& sender);
+    void setSenderReplyTo(const QString& replyto);
     void setRecipientAddress(const QString& recipient);
     void setMessageSubject(const QString& subject);
     void setMessageBody(const QString& message);
@@ -141,6 +142,7 @@ private:
     bool finished;
     
     QString senderAddress;
+    QString senderReplyTo;
     QString recipientAddress;
     QString messageSubject;
     QString messageBody;
