@@ -6,8 +6,8 @@
  */
 
 
-#include "../../lib/splay/splayPlugin.h"
-#include "../../lib/tplay/tplayPlugin.h"
+#include "../../lib/decoder/splayPlugin.h"
+#include "../../lib/decoder/tplayPlugin.h"
 #include "../../lib/decoder/vorbisPlugin.h"
 #include "../../lib/input/bufferInputStream.h"
 #include "../../lib/output/avSyncer.h"
@@ -31,31 +31,23 @@ int main(int argc, char** argv) {
   // 
   // you cannot set the input _before_ the output 
   // in fact you can, but this gives you a segfault!
-  while(1) {
-  DecoderPlugin* plugin=new VorbisPlugin();
-  //TplayPlugin* plugin=new TplayPlugin();
-  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL,true);
 
+  SplayPlugin* plugin=new SplayPlugin();
+  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL,true);
   InputStream* in=InputPlugin::createInputStream(argv[1],true);
 
-
-  // The plugin does not do "open"
   in->open(argv[1]);
-
   // watch the order!
   plugin->setOutputPlugin(out);
   plugin->setInputPlugin(in);
-
   plugin->play();
 
-  /*
   while(plugin->getStreamState() != _STREAM_STATE_EOF) {
     cout << "check state"<<endl;
-    sleep(1);
+    TimeWrapper::sleep(1);
 
   }
-  */
-  sleep(4);
+
   cout << "****************plugin eof"<<endl;
   //out->audioClose();
   plugin->close();
@@ -63,7 +55,6 @@ int main(int argc, char** argv) {
   delete plugin;
   delete in;
   delete out;
-  }
-  
+  return(0);  
 }
   
