@@ -9,10 +9,10 @@
  */
 
 
-#include "../../lib/tplay/tplayPlugin.h"
+#include "../../lib/decoder/tplayPlugin.h"
 #include "../../lib/decoder/nukePlugin.h"
 
-#include "../../lib/util/audio/audioWrapper.h"
+
 
 
 int main(int argc, char** argv) {
@@ -51,7 +51,7 @@ int main(int argc, char** argv) {
   plugin->play();
 
   while(plugin->getStreamState() != _STREAM_STATE_EOF) {
-    sleep(1);
+    TimeWrapper::sleep(1);
   }
   cout << "plugin eof"<<endl;
   plugin->close();
@@ -59,6 +59,6 @@ int main(int argc, char** argv) {
   delete plugin;
   delete in;
   delete out;
-
+  return(0);
 }
   
