@@ -43,6 +43,11 @@ InputStream* InputPlugin::createInputStream(int inputType) {
     inputStream=new FileInputStream();
     break;
   }
+  case __INPUT_CDDA: {
+    inputStream=new CDDAInputStream();
+    break;
+  }
+
   case __INPUT_HTTP: {
     inputStream=new HttpInputStream();
     break;
@@ -59,6 +64,16 @@ InputStream* InputPlugin::createInputStream(int inputType) {
   return inputStream;
 }
 
+InputStream* InputPlugin::createInputStream(int inputType,int lThreadSafe) {
+  InputStream* input=InputPlugin::createInputStream(inputType);
+  if (lThreadSafe == false) {
+    return input;
+  }
+  InputStream* tsInput=new ThreadSafeInputStream(input);
+  return tsInput;
+}
+
+
 InputStream* InputPlugin::createInputStream(const char* dest) {
   int method;
 
@@ -66,3 +81,10 @@ InputStream* InputPlugin::createInputStream(const char* dest) {
   return (InputPlugin::createInputStream(method));
 }
 
+
+InputStream* InputPlugin::createInputStream(const char* dest,int lThreadSafe) {
+  int method;
+
+  method=InputPlugin::getInputType(dest);
+  return (InputPlugin::createInputStream(method,lThreadSafe));
+}
