@@ -13,12 +13,17 @@
 
 #include "mpegSystemStream.h"
 
+#define _RESYNC_STATE_INIT                0
+#define _RESYNC_STATE_NEED_PACKET         1
+#define _RESYNC_STATE_NEED_START          2
+
 
 
 
 MpegSystemStream::MpegSystemStream(InputStream* input) {
   this->input=input;
   syncCode=0xff;  // invalid
+  lState=_RESYNC_STATE_INIT;
 }
 
 
@@ -53,6 +58,7 @@ int MpegSystemStream::firstInitialize(MpegSystemHeader* mpegHeader) {
   if (readSyncCode() == false) {
     return false;
   }
+  
   if (syncCode == _SEQ_START_CODE) {
     // If we found a seq_heade_start code we assume
     // that we are a video only stream
@@ -63,12 +69,14 @@ int MpegSystemStream::firstInitialize(MpegSystemHeader* mpegHeader) {
     mpegHeader->setLayer(_PACKET_NO_SYSLAYER);     // no syslayer
     mpegHeader->setPacketID(_PAKET_ID_VIDEO);
     mpegHeader->setPacketLen(8192);
-
+    mpegHeader->resetAvailableLayers();
     return true;
   } else {
     if (syncCode == _PACK_START_CODE) {
       if (processStartCode(syncCode,mpegHeader)==true) {
 	mpegHeader->setLayer(_PACKET_SYSLAYER);     // syslayer
+	mpegHeader->resetAvailableLayers();
+	lState=_RESYNC_STATE_NEED_START;
 	return true;
       }
 
@@ -77,6 +85,11 @@ int MpegSystemStream::firstInitialize(MpegSystemHeader* mpegHeader) {
   return false;
 }
 
+void MpegSystemStream::reset() {
+  lState=_RESYNC_STATE_NEED_PACKET;
+}
+
+
 int MpegSystemStream::nextPacket(MpegSystemHeader* mpegHeader) {
   int layer=mpegHeader->getLayer();
   if (layer == _PACKET_NO_SYSLAYER) {
@@ -86,8 +99,15 @@ int MpegSystemStream::nextPacket(MpegSystemHeader* mpegHeader) {
   if (readSyncCode() == false) {
     return false;
   }
-  if (syncCode == _PACK_START_CODE) {
+  if ((syncCode & 0xFFFFFF00) == 0x00000100) {
+    if (lState == _RESYNC_STATE_NEED_PACKET) {
+      if (syncCode != _PACK_START_CODE) {
+	return false;
+      }
+      lState=_RESYNC_STATE_NEED_START;
+    }
     if (processStartCode(syncCode,mpegHeader) == false) {
+      reset();      
       return false;
     }
     return true;
@@ -171,17 +191,13 @@ int MpegSystemStream::processStartCode(unsigned int startCode,
   mpegHeader->setPacketLen(0);
   mpegHeader->setPacketID(_PAKET_ID_NUKE);
 
-  if (startCode != _PACK_START_CODE) {
-    return false;
-  }
-  lok=processPackHeader(mpegHeader);
-  if (lok == false) {
-    printf("Error in reading pack header\n");
-    return false;
-  }
-  if (readHeader(&startCode) == false) {
-    printf("readHeader 1: is %8x\n",startCode);
-    return false;
+  if (startCode == _PACK_START_CODE) {
+    lok=processPackHeader(mpegHeader);
+    if (lok == false) {
+      printf("Error in reading pack header\n");
+      return false;
+    }
+    return true;
   }
   if (startCode == _SYSTEM_HEADER_START_CODE) {
     lok = processSystemHeader(mpegHeader);
@@ -189,12 +205,14 @@ int MpegSystemStream::processStartCode(unsigned int startCode,
       fprintf(stderr, "Error in reading system header\n");
       return false;
     }
-    if (readHeader(&startCode) == false) {
-      printf("readHeader 2: is %8x\n",startCode);
-      return false;
-    }    
+    return true;
   }
-  return processPacket(startCode,mpegHeader);
+  // handle default
+  lok=processPacket(startCode,mpegHeader);
+  if (lok == false) {
+    return false;
+  }
+  return true;
 }
 
 
@@ -309,8 +327,10 @@ int MpegSystemStream::processSystemHeader(MpegSystemHeader* mpegHeader) {
   }  
   mpegHeader->resetAvailableLayers();
   int i = 6;
-  while ((inputBuffer[i] & 0x80) && (i<headerSize)  ) {
-    mpegHeader->addAvailableLayer(inputBuffer[i]);
+  while (i<headerSize) {
+    if (inputBuffer[i] & 0x80) {
+      mpegHeader->addAvailableLayer(inputBuffer[i]);
+    }
     i += 3;
   }
   free(inputBuffer);
@@ -429,16 +449,18 @@ int MpegSystemStream::processPrivateHeader(MpegSystemHeader* mpegHeader) {
   int one=getByteDirect();  
   pos++;
   mpegHeader->setSubStreamID(one);
-  switch(one) {
-  case _SUBSTREAM_AC3_ID:
+  switch(one>>4) {
+  case _SUBSTREAM_AC3_ID>>4:
     input->read(nukeBuffer,3);
+    mpegHeader->addAvailableLayer(one);
+    cout << "addAvailableLayer:"<<one<<endl;
     pos+=3;
     break;
-  case _SUBSTREAM_LPCM_ID:
+  case _SUBSTREAM_LPCM_ID>>4:
     input->read(nukeBuffer,6);
     pos+=6;
     break;
-  case _SUBSTREAM_SUBPIC_ID:
+  case _SUBSTREAM_SUBPIC_ID>>4:
     input->read(nukeBuffer,3);
     pos+=3;
     break;
