@@ -43,8 +43,8 @@ void PluginInfo::reset(){
 }
 
 void PluginInfo::print() {
-  cout << "length in sec:"<<sec<<endl;
-  cout << "url:"<<getUrl()<<endl;
+  cerr << "length in sec:"<<sec<<endl;
+  cerr << "url:"<<getUrl()<<endl;
 }
 
 
