@@ -54,6 +54,10 @@ void ImageBase::putImage() {
   cout << "direct virtual call: ImageBase::putImage  "<<endl;
 }
 
+void ImageBase::putImage(int ,int ) {
+  cout << "direct virtual call: ImageBase::putImage(w,h)  "<<endl;
+}
+
 void ImageBase::setIdentifier(const char *id)
 {
 	if (identifier != NULL)
