@@ -22,6 +22,8 @@
 
 #include "yuvPicture.h"
 
+class ImageBase;
+
 class Surface {
 
  public:
@@ -29,18 +31,21 @@ class Surface {
   virtual ~Surface();
 
   virtual int isOpen();
-  virtual int open(int width, int height,const char *title);
+  virtual int open(int width, int height,const char *title, bool border=false);
   virtual int close();
   virtual int getHeight();
   virtual int getWidth();
   virtual int getDepth();
+  virtual int getImageMode();
 
-  virtual int openImage(int imageSize,int imageMode);
+  virtual ImageBase *findImage(int imageMode);
+
+  virtual int openImage(int mode, YUVPicture* pic = NULL);
   virtual int closeImage();
   virtual int dither(YUVPicture* pic);
   virtual int putImage(YUVPicture* pic);
 
-  virtual int checkEvent(int* mode,int* size);
+  virtual int checkEvent(int* mode);
 
   // config surface
   virtual void config(const char* key, 
