@@ -357,8 +357,7 @@ int ImageXVDesk::haveXVSupport(XWindow* xWindow) {
 void ImageXVDesk::freeImage() {
 #ifdef X11_XV
   if (xWindow == NULL) {
-	  cout << "ImageXVDesk::freeImage - no image was created!" << endl;
-	  return;
+    return;
   }
   if (yuv_shminfo.shmid >=0) {
     XShmDetach(xWindow->display,&yuv_shminfo);
