@@ -12,22 +12,26 @@
 
 #include "decoderBaseObject_impl.h"
 #include "../mpeglib/lib/decoder/decoderPlugin.h"
-#include "../mpeglib/lib/splay/splayPlugin.h"
+#include "../mpeglib/lib/decoder/splayPlugin.h"
 #include "debug.h"
 
 // define this to run the playobject without the
 // arts backend. (usefull to check if a bug is in arts or mpeglib)
 //#define _STRIP_ZERO
 
+using namespace Arts;
+
 static int instanceCnt=0;
 
-DecoderBaseObject_impl::DecoderBaseObject_impl() {
+DecoderBaseObject_impl::DecoderBaseObject_impl()
+    : _speed(1.0f)
+{
 
   flpos=0.0;
   _blocking = false;
 #ifdef _STRIP_ZERO
   outputStream=NULL;
-#else 
+#else
   outputStream=new ArtsOutputStream(NULL);
   arts_debug("outputStream created");
   decoderPlugin=NULL;
@@ -63,8 +67,8 @@ DecoderPlugin* DecoderBaseObject_impl::createPlugin() {
 }
 
 
-InputStream* DecoderBaseObject_impl::createInputStream(const char* url) {
-  InputStream* back=InputPlugin::createInputStream(url,true);
+::InputStream* DecoderBaseObject_impl::createInputStream(const char* url) {
+  ::InputStream* back=InputPlugin::createInputStream(url,true);
   return back;
 }
 
@@ -118,13 +122,13 @@ bool DecoderBaseObject_impl::loadMedia(const string &filename) {
 string DecoderBaseObject_impl::description() {
   arts_debug("description");
   string back;
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return back;
 #endif
   PluginInfo* pluginInfo=decoderPlugin->getPluginInfo();
   pluginInfo->print();
   return back;
-  
+
 }
 
 void DecoderBaseObject_impl::description(const string &) {
@@ -134,9 +138,9 @@ void DecoderBaseObject_impl::description(const string &) {
 
 poTime DecoderBaseObject_impl::currentTime() {
   poTime time;
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return time;
-#endif  
+#endif
   AudioTime* audioTime=outputStream->getAudioTime();
   float currentTime=audioTime->getTime()+(float)startTime;
   time.seconds=(long)(currentTime);
@@ -148,9 +152,9 @@ poTime DecoderBaseObject_impl::currentTime() {
 
 poTime DecoderBaseObject_impl::overallTime() {
   poTime time;
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return time;
-#endif  
+#endif
 
   PluginInfo* pluginInfo=decoderPlugin->getPluginInfo();
   time.seconds=pluginInfo->getLength();
@@ -160,9 +164,9 @@ poTime DecoderBaseObject_impl::overallTime() {
 
 poCapabilities DecoderBaseObject_impl::capabilities() {
   arts_debug("capabilities");
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return capSeek;
-#endif  
+#endif
   PluginInfo* pluginInfo=decoderPlugin->getPluginInfo();
   long len=pluginInfo->getLength();
   if (len == 0) {
@@ -196,10 +200,10 @@ void DecoderBaseObject_impl::play() {
 }
 
 void DecoderBaseObject_impl::seek(const class poTime& seekTime) {
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return;
 #endif
-  
+
   long sec=seekTime.seconds;
 
   arts_debug("sec in plugin is %d:", sec);
@@ -211,8 +215,8 @@ void DecoderBaseObject_impl::seek(const class poTime& seekTime) {
   // if the thread blocks on the artsOutputstream: kick him out
   // the next command will the the seek command
   outputStream->audioClose();
- 
-  
+
+
   // thread blocking allowed
   outputStream->audioOpen();
   arts_debug("************ reopen");
@@ -240,10 +244,10 @@ void DecoderBaseObject_impl::halt() {
   _state=posIdle;
   shudownPlugins();
 }
- 
+
 
 void DecoderBaseObject_impl::streamInit() {
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return;
 #endif
 
@@ -256,17 +260,17 @@ void DecoderBaseObject_impl::streamStart() {
 int DecoderBaseObject_impl::fillArts(unsigned long samples,
 				     float* left , float* right) {
   unsigned long haveSamples = 0;
-  
+
   AudioTime* audioTime=outputStream->getAudioTime();
   int wav_samplingRate=audioTime->getSpeed();
   int wav_sampleWidth=audioTime->getSampleSize();
   int wav_channelCount=audioTime->getStereo()+1;
-  
+
   if(doFloat()) wav_sampleWidth = sizeof(float)*8;
 
   // here seems to be an error, I have clicks sometimes in the stream
   int byteMultiplikator=(wav_sampleWidth/8)*wav_channelCount;
-  
+
   char* buffer;
   int hasBytes = 0;
   int wantBytes = 0;
@@ -277,7 +281,7 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
   }
 
   /* difference between the sampling rates in percent */
-  float diff = fabs((double)wav_samplingRate - (double)samplingRateFloat)
+  float diff = fabs((double)wav_samplingRate - (double)(samplingRateFloat/_speed))
              / (double)samplingRateFloat;
 
   /*
@@ -285,7 +289,7 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
    * 1. decoder -> float rendering
    * 2. no resampling (i.e. artsd running @ 44100 Hz, playing an 44100 Hz mp3)
    */
-  if(_state == posPlaying && doFloat() && diff < 0.02) {
+  if(_state == posPlaying && doFloat() && diff < 0.0005) {
     wantBytes = sizeof(float) * wav_channelCount * samples;
     hasBytes = outputStream->read(&buffer,wantBytes);
     float *flptr = (float *)buffer;
@@ -314,11 +318,11 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
     // since the samplingrate of the MP3 and the samplingrate of the output
     // device (soundcard) are not necessarily the same, it's a bit tricky
     //
-    
+
     // calculate "how fast" we consume input samples (2.0 means, we need 2
     // input samples to generate one output sample)
-    double speed = (double)wav_samplingRate / (double)samplingRateFloat;
-    
+    double speed = (double)wav_samplingRate / (double)(samplingRateFloat/_speed);
+
     // calculate how many input samples we need, then to satisfy the request
     // use a larger amount than "really" required, to ensure that samples are
     // available for rounding errors and interpolation
@@ -332,14 +336,14 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
 
     // convert those bytes into the suitable output form
     haveSamples = uni_convert_stereo_2float(samples, (unsigned char *)buffer,
-					    hasBytes, wav_channelCount, 
+					    hasBytes, wav_channelCount,
 					    format,
 					    left,right,speed,flpos);
 
     // calculate where we are now (as floating point position) in our
     // inputsample buffer
     flpos += (double)haveSamples * speed;
-    
+
     // Good - so how many input samples we won't need anymore (for the
     // next request)? Skip them.
     int skip = (int)floor(flpos);
@@ -352,11 +356,11 @@ int DecoderBaseObject_impl::fillArts(unsigned long samples,
 
     outputStream->forwardReadPtr(forward);
   }
-  
+
   if(haveSamples != samples) {
-    
+
     unsigned long i;
-    
+
     for(i=haveSamples;i<samples;i++)
       left[i] = right[i] = 0.0;
 
@@ -368,12 +372,11 @@ void DecoderBaseObject_impl::calculateBlock(unsigned long samples,
 					    float* left , float* right) {
 
 
-#ifndef _STRIP_ZERO  
+#ifndef _STRIP_ZERO
 
   int audioState=outputStream->waitStreamState(_OUTPUT_WAIT_METHOD_POLL,
 					       _STREAM_MASK_ALL,
 					       _STREAMTYPE_AUDIO);
-
   if (audioState & _STREAM_MASK_IS_INIT) {
     // now check if we already have enough data
     int lenough=false;
@@ -385,7 +388,7 @@ void DecoderBaseObject_impl::calculateBlock(unsigned long samples,
 
       lenough=true;
     }
-    if (outputStream->getBufferFillgrade() > 8192) {
+    if (outputStream->getBufferFillgrade() >= 0) {
       lenough=true;
     }
     if ( ((lenough) || _blocking) && (_state == posPlaying) ) {
@@ -403,7 +406,7 @@ void DecoderBaseObject_impl::calculateBlock(unsigned long samples,
 }
 
 void DecoderBaseObject_impl::streamEnd() {
-#ifdef _STRIP_ZERO  
+#ifdef _STRIP_ZERO
   return;
 #endif
   halt();
@@ -499,3 +502,13 @@ bool DecoderBaseObject_impl::blocking()
 {
   return _blocking;
 }
+
+void DecoderBaseObject_impl::speed(float newValue)
+{
+    _speed= newValue;
+}
+
+float DecoderBaseObject_impl::speed()
+{
+    return _speed;
+}
