@@ -16,12 +16,10 @@
 
 
 #include "decoderBaseObject_impl.h"
-#include "../mpeglib/lib/mpgplayer/mpgPlugin.h"
+#include "../mpeglib/lib/decoder/mpgPlugin.h"
 
 
 
-using namespace Arts;
-
 class MPGPlayObject_impl: 
  virtual public DecoderBaseObject_impl,
  virtual public MPGPlayObject_skel {
