@@ -6,7 +6,7 @@
 #include <job.h>
 
 class QFile;
-class PlayListItem;
+class PlaylistItem;
 class QTimer;
 
 
@@ -18,7 +18,7 @@ class Downloader : public QObject
 Q_OBJECT
 	struct QueueItem
 	{
-		PlayListItem *notifier;
+		PlaylistItem *notifier;
 		KURL file;
 		QString local;
 	};
@@ -27,8 +27,8 @@ public:
 	Downloader(QObject *parent=0);
 	virtual ~Downloader();
 
-	QString enqueue(PlayListItem *notifier, const KURL &file);
-	void dequeue(PlayListItem *notifier);
+	QString enqueue(PlaylistItem *notifier, const KURL &file);
+	void dequeue(PlaylistItem *notifier);
 
 private:
 	void getNext();
