@@ -1,49 +1,49 @@
 #include "playlistsaver.h"
 
 
-PlayListSaver::PlayListSaver(const QString &file)
+PlaylistSaver::PlaylistSaver(const QString &file)
 	: KSimpleConfig(file)
 {
 	writeEntry("NoatunPlaylist", true);
 	writeEntry("FormatVersion", "0.99");
 }
 
-PlayListSaver::~PlayListSaver()
+PlaylistSaver::~PlaylistSaver()
 {
 
 }
 
-QString PlayListSaver::title()
+QString PlaylistSaver::title()
 {
 	setGroup("");
 	return readEntry("title");
 }
 
-void PlayListSaver::setTitle(const QString &title)
+void PlaylistSaver::setTitle(const QString &title)
 {
 	setGroup("");
 	writeEntry("title", title);
 }
 
-QDateTime PlayListSaver::date()
+QDateTime PlaylistSaver::date()
 {
 	setGroup("");
 	return readDateTimeEntry("date");
 }
 
-QString PlayListSaver::location()
+QString PlaylistSaver::location()
 {
 	setGroup("");
 	return readEntry("date");
 }
 
-bool PlayListSaver::isPlayList(const QString &file)
+bool PlaylistSaver::isPlaylist(const QString &file)
 {
 	KSimpleConfig f(file);
 	return f.readBoolEntry("NoatunPlaylist");
 }
 
-QStringList PlayListSaver::fileList() const
+QStringList PlaylistSaver::fileList() const
 {
 	QStringList list=groupList().grep("File-.*");
 	for(QStringList::Iterator it=list.begin(); it != list.end(); ++it )
@@ -51,20 +51,20 @@ QStringList PlayListSaver::fileList() const
 	return list;	
 }
 
-QString &PlayListSaver::stripFilePre(QString &f)
+QString &PlaylistSaver::stripFilePre(QString &f)
 {
 	if (f.right(5)=="File-")
 		return f=f.left(f.length()-5);
 	return f;
 }
 
-QString PlayListSaver::file() const
+QString PlaylistSaver::file() const
 {
 	QString gr=group();
 	return stripFilePre(gr);
 }
 
-void PlayListSaver::setFile(const QString &file)
+void PlaylistSaver::setFile(const QString &file)
 {
 	setGroup("File-"+file);
 }
