@@ -3,18 +3,18 @@
 
 #include <ksimpleconfig.h>
 
-class PlayListSaver : public KSimpleConfig
+class PlaylistSaver : public KSimpleConfig
 {
 public:
-	PlayListSaver(const QString &file);
-	~PlayListSaver();
+	PlaylistSaver(const QString &file);
+	~PlaylistSaver();
 	
 	QString title();
 	void setTitle(const QString &title);
 	QDateTime date();
 	QString location();
 	
-	static bool isPlayList(const QString &file);
+	static bool isPlaylist(const QString &file);
 	
 	QStringList fileList() const;
 	
