@@ -14,7 +14,7 @@ class IDPrefs : public CModule
 {
 Q_OBJECT
 public:
-	IDPrefs(QWidget *parent, char *name=0);
+	IDPrefs(QObject *parent);
 	virtual void save();
 
 public slots:
