@@ -31,9 +31,7 @@ InfraRed::InfraRed()
 	        SLOT(slotCommand(const QString &, const QString &, int)));
 
 	IRPrefs::s_lirc = m_lirc;
-	(void) NoatunPrefAdd(this,IRPrefs,
-	                     i18n("Infrared Control"),
-						 i18n("Configure the Infrared Commands"));
+	new IRPrefs(this);
 }
 
 InfraRed::~InfraRed()
