@@ -24,6 +24,9 @@
 #include <qdragobject.h>
 #include <iostream.h>
 #include <math.h>
+#include <noatunstdaction.h>
+#include <stdlib.h>
+#include <unistd.h>
 
 class KJToolTip : public QToolTip
 {
@@ -63,12 +66,14 @@ static int isGray(QRgb r)
 	       (qRed(r) == qBlue(r));
 }
 
+KJLoader *KJLoader::kjofol=0;
+
 KJLoader::KJLoader()
 	: QWidget(0,"KJLoader", WType_TopLevel | WStyle_NoBorder |WRepaintNoErase),
 	  UserInterface(), moving(false), mClickedIn(0), mText(0), mNumbers(0)
 {
-	NOATUNPLUGINC(KJLoader);
-
+	kjofol=this;
+	
 	mTooltips=new KJToolTip(this);
 	setCaption("Noatun");
 	
@@ -76,10 +81,11 @@ KJLoader::KJLoader()
 	
 	KConfig *config=KGlobal::config();
 	config->setGroup("KJofol-Skins");
-	QString skin=config->readEntry("SkinResource", "kjofol");
-	skin=getFullPath(skin);
+	QString skin=config->readEntry("SkinResource", locate("data", "noatun/kjskins/kjofol/kjofol.rc"));
 	if (QFile(skin).exists())
+	{
 		loadSkin(skin);
+	}
 	else
 	{
 		KNotifyClient::event("warning",
@@ -91,13 +97,12 @@ KJLoader::KJLoader()
 	setAcceptDrops(true);
 	
 	mHelpMenu =new KHelpMenu(this, kapp->aboutData());
-	connect(napp->player(), SIGNAL(timeout()), this, SLOT(timeUpdate()));	
-	connect(napp->player(), SIGNAL(newSong()), this, SLOT(newSong()));
+	connect( napp->player(), SIGNAL(timeout()), this, SLOT(timeUpdate()));
+	connect( napp->player(), SIGNAL(newSong()), this, SLOT(newSong()));
 	connect( napp->player(), SIGNAL(hideYourself()), this, SLOT(hide()) );
 	connect( napp->player(), SIGNAL(showYourself()), this, SLOT(show()) );
 
-	(void)NoatunPrefAdd(this, KJPrefs, i18n("K-Jofol Skins"), 
-	              i18n("Skin Selection For the K-Jofol Plugin"));
+	new KJPrefs(this); 
 	QApplication::restoreOverrideCursor();
 	newSong();
 }
@@ -124,25 +129,87 @@ void KJLoader::addChild(KJWidget *c)
 	subwidgets.append(c);
 }
 
+// GAMMA CORRECTION SUCKS!!! ROT IN HELL QIMAGEIO!!!
+
+// just like gamma correction, this function is a stupid hack
+bool KJLoader::cleanSkin(const QString &dir)
+{
+	// try to guess the current filetype:
+	// BMP, JPEG, PNG
+	
+	QString ext;
+	QDir d(dir);
+	
+	QStringList files=d.entryList();
+	if (files.grep("png", false).count())
+		return true;
+	
+	if (files.grep("bmp", false).count())
+		ext="bmp";
+	if (files.grep("jpeg", false).count())
+		ext="jpeg";
+	if (files.grep("jpg", false).count())
+		ext="jpg";
+
+	if (::access(dir.latin1(), W_OK)!=0) return false;
+
+	QString command="/bin/sh "+::locate("exe", "noatun_kjofol_fixskin.sh");
+	command+=" '"+dir+"' "+ext;
+	::system(command.latin1());
+	return true;
+}
+
+QString KJLoader::guessRcFile(const QString &dir)
+{
+	QString path=dir;
+	if (path[path.length()-1]=='/')
+		path=path.left(path.length()-1);
+
+	QString tests=path+"/";
+	QString possible=path.mid(path.findRev("/")+1);
+	tests+=possible+".rc";
+	tests=filenameNoCase(tests);
+	if (tests.length())
+		return tests;
+	
+	QDir d(path, "*.rc");
+	
+	if (d.count()) return path+"/"+d[0];
+
+	return "";
+}
+
 void KJLoader::loadSkin(const QString &file)
 {
 	if (file==mCurrentSkin) return;
 	mCurrentSkin=file;
 	unloadSkin();
-			
-	Parser::open(file);
+	
+	if (!cleanSkin(file.left(file.findRev("/"))))
+	{
+		KNotifyClient::event("warning",
+			i18n("There was trouble loading skin %1. Please select another skin file.").arg(file));
+		napp->preferences();
+		return;
+	}
+	
+	Parser::open(filenameNoCase(file));
 
 	
 	mText = new KJFont("Font", this);
 	mNumbers = new KJFont("TimeFont", this);
 	
 	subwidgets.append(new Background(this));
-	subwidgets.append(new KJSeeker(item("SeekRegion"), this));
 
-	subwidgets.append(new KJVolumeBMP(item("VolumeControlButton"), this));
-	subwidgets.append(new KJFilename(item("FilenameWindow"), this));
-	subwidgets.append(new KJTime(item("MP3TimeWindow"), this));
-	subwidgets.append(new KJVis(item("AnalyzerWindow"), this));
+	if (exist("VolumeControlButton"))
+		subwidgets.append(new KJVolumeBMP(item("VolumeControlButton"), this));
+	if (exist("FilenameWindow"))
+		subwidgets.append(new KJFilename(item("FilenameWindow"), this));
+	if (exist("MP3TimeWindow"))
+		subwidgets.append(new KJTime(item("MP3TimeWindow"), this));
+	if (exist("AnalyzerWindow"))
+		subwidgets.append(new KJVis(item("AnalyzerWindow"), this));
+	QTimer::singleShot(0, this, SLOT(loadSeeker()));
 //	subwidgets.append(new KJScope(item("AnalyzerWindow"), this));
 //	subwidgets.append(new KJEqualizer(item("EqualizerWindow"), this));
 	
@@ -161,6 +228,11 @@ void KJLoader::loadSkin(const QString &file)
 //		newSong();
 }
 
+void KJLoader::loadSeeker()
+{
+	subwidgets.append(new KJSeeker(item("SeekRegion"), this));
+}
+
 void KJLoader::unloadSkin()
 {
 	subwidgets.clear();
@@ -181,8 +253,8 @@ void KJLoader::closeEvent(QCloseEvent*)
 
 void KJLoader::dragEnterEvent(QDragEnterEvent *event)
 {
-    // accept uri drops only
-    event->accept(QUriDrag::canDecode(event));
+	// accept uri drops only
+	event->accept(QUriDrag::canDecode(event));
 }
 
 void KJLoader::dropEvent(QDropEvent *event)
@@ -235,7 +307,7 @@ void KJLoader::mousePressEvent(QMouseEvent *e)
 	setActiveWindow();
 	
 	if (e->button()==RightButton)
-		napp->showContextMenu();
+		NoatunStdAction::ContextMenu::showContextMenu();
 	else
 	{
 	
@@ -269,13 +341,13 @@ void KJLoader::mouseReleaseEvent(QMouseEvent *e)
 		mClickedIn=0;
 	}
 
-	moving=false;	
+	moving=false;
 }
 
 void KJLoader::timeUpdate()
 {
 	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
-		i->timeUpdate(napp->player()->getTime());
+		i->timeUpdate(napp->player()->getTime()/1000); // pass seconds to all Widgets
 }
 
 void KJLoader::newSong()
@@ -474,7 +546,7 @@ void KJButton::mouseRelease(const QPoint &, bool in)
 		napp->player()->playpause();
 	else if (mTitle=="OpenFileButton")
 	{
-		KURL file(KFileDialog::getOpenURL(0, napp->shellGlob(), parent(),
+		KURL file(KFileDialog::getOpenURL(0, napp->mimeTypes(), parent(),
 		                                  i18n("Select a File to Play")));
 		if (!file.isMalformed())
 			napp->player()->openFile(file);
@@ -606,18 +678,24 @@ void KJSeeker::mouseRelease(const QPoint &pos, bool in)
 	g=grayRgb(color);
 	repaint();
 
-	napp->player()->skipTo(g*1000/255);
+	napp->player()->skipTo(g*napp->player()->getLength()/255);
 	return;
 
 }
 
-void KJSeeker::timeUpdate(int mille)
+void KJSeeker::timeUpdate(int sec)
 {
-	if (mille>1000)
-		mille=1000;
-	else if (mille<0)
-		mille=0;
-	g=mille*255/1000;
+	int length = napp->player()->getLength() / 1000;
+	if (length<1)
+		length=1;
+
+	if (sec > length)
+		sec = length;
+	else if ( sec < 0 )
+		sec=0;
+
+	g = sec * 255 / length;
+//	fprintf(stderr,"sec: %d, len: %d, g: %d\n", sec, length, g);
 	QPainter p(parent());
 	paint(&p, rect());
 }
@@ -708,8 +786,8 @@ KJFont::KJFont(const QString &prefix, KJLoader *parent)
 	}
 	else
 	{
-		mString[0]="abcdefghijklmnopqrstuvwxyz\"@@";
-		mString[1]="0123456789 _:()-'!_+\\/[]*& .=$#";
+		mString[0]="abcdefghijklmnopqrstuvwxyz\"@";
+		mString[1]="0123456789;_:()-'!_+\\/[]*&%.=$#";
 		mString[2]="?*,                          ";
 		mNullChar=' ';
 	}
@@ -851,7 +929,8 @@ bool KJTime::mousePress(const QPoint &)
 
 void KJTime::timeUpdate(int)
 {
-	if (!napp->player()->current()) return;
+	if (!napp->player()->current())
+		return;
 	QCString time=napp->player()->lengthString().latin1();
 	time=time.left(time.find('/'));
 
@@ -993,7 +1072,7 @@ void KJScope::scopeEvent(float *d, int size)
 	int heightHalf=mHeight/2;
 	y+=heightHalf;
 
-	while (d<=end)
+	while (d<end)
 	{
 		// clip
 		float n=*d;
