@@ -1,7 +1,6 @@
 #ifndef KJPREFS_H
 #define KJPREFS_H
 
-#include <qvariant.h>
 #include <qwidget.h>
 #include <noatunpref.h>
 
@@ -17,7 +16,7 @@ class KJPrefs : public CModule
 { 
 Q_OBJECT
 public:
-	KJPrefs(QWidget* parent = 0, char* name = 0);
+	KJPrefs(QObject* parent);
 	virtual void save();
 	virtual void reopen();
 
@@ -32,6 +31,13 @@ private:
 	QPixmap mPixmap;
 };
 
-QString getFullPath(const QString &file);
+/**
+ * resolve a filename to it's correct case.
+ * badNodes is the amount of directories/files (at the end)
+ * that aren't known)
+ **/
+QString filenameNoCase(const QString &filename, int badNodes=1);
 
 #endif // FORM1_H
+
+
