@@ -10,9 +10,13 @@ NOATUNPLUGIND
 
 public:
 	Monoscope();
+	virtual ~Monoscope();
 
 	void init();
 
+public slots:
+	void toggle(void);
+
 protected:
 	virtual void closeEvent(QCloseEvent *);
 	virtual void scopeEvent(float *data, int bands);
@@ -21,6 +25,7 @@ protected:
 
 private:
 	QRgb mHighColor, mLowColor;
+	int pluginMenuItem;
 };
 
 #endif
