@@ -6,10 +6,10 @@
 class VoicePrint : public QWidget,  public MonoFFTScope, public Plugin
 {
 Q_OBJECT
-NOATUNPLUGIND
 
 public:
 	VoicePrint();
+	virtual ~VoicePrint();
 
 	void setColors(const QColor &bg, const QColor &fg, const QColor &l);
 	void init();
@@ -20,6 +20,9 @@ protected:
 	virtual void resizeEvent(QResizeEvent *);
 	virtual void paintEvent(QPaintEvent *);
 
+public:
+	static VoicePrint* voicePrint;
+	
 private:
 	QColor mProgress;
 	QPixmap mBuffer;
