@@ -45,14 +45,12 @@ class SpectrumImage {
   int width;
 
  public:
-  SpectrumImage(int height);
+  SpectrumImage(int height, int width);
   ~SpectrumImage();
 
   QPixmap* getPixmap();
   int getHeight();
- 
- private:
-  void fillImage();
+  void fillImage(float *data);
 
 };
 
